@@ -45,6 +45,8 @@ class WebhookTestingGateway(object):
             return self.__merchant_account_declined_sample_xml(id)
         elif kind == WebhookNotification.Kind.TransactionDisbursed:
             return self.__transaction_disbursed_sample_xml(id)
+        elif kind == WebhookNotification.Kind.TransactionReviewed:
+            return self.__transaction_reviewed_sample_xml(id)
         elif kind == WebhookNotification.Kind.TransactionSettled:
             return self.__transaction_settled_sample_xml(id)
         elif kind == WebhookNotification.Kind.TransactionSettlementDeclined:
@@ -119,6 +121,17 @@ class WebhookTestingGateway(object):
             </transaction>
         """ % id
 
+    def __transaction_reviewed_sample_xml(self, id):
+        return """
+            <transaction-review>
+              <transaction-id>%s</transaction-id>
+              <decision>a smart decision</decision>
+              <reviewer-email>hey@girl.com</reviewer-email>
+              <reviewer-note>I reviewed this</reviewer-note>
+              <reviewed-time type="datetime">2021-04-20T06:09:00Z</reviewed-time>
+            </transaction-review>
+        """ % id
+
     def __transaction_settled_sample_xml(self, id):
         return """
             <transaction>
